==> drop_account-2.3.1.tar.gz: drop_account/l10n/zh_TW.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) 刪除了他們的帳號",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) 刪除了他們的帳號",
    "%1$s deleted their account" : "%1$s 刪除了他們的帳號",
    "An user <strong>deleted</strong> its account" : "An user <strong>刪除了</strong>他的帳號",
    "User-Session unexpectedly expired" : "用戶會話意外過期",
    "Successfully sent email" : "電子郵件傳送成功",
    "You have no email set up into your account" : "您的帳號沒有設定電子郵件",
    "Unexpected error sending email. Please contact your administrator." : "傳送電子郵件時發生意外的錯誤。請聯絡您的系統管理員。",
    "Hello," : "歡迎，",
    "Delete account" : "刪除帳號",
    "Cheers!" : "乾杯！",
    "User account deletion" : "刪除使用者帳號",
    "An app to allow users to delete their accounts." : "app 允許使用者刪除他們的帳號.",
    "Account deletion" : "刪除帳號",
    "Allows users to delete themselves their own account." : "允許使用者刪除他們自己的帳號。",
    "Email confirmation" : "電子郵件確認",
    "Require confirmation by email" : "需要透過電子郵件確認",
    "Will require users to click a confirmation link sent by email to confirm their action." : "要求使用者點擊通過電子郵件發送的確認連結來確認其操作。",
    "Delete my account" : "刪除我的帳號",
    "Deleting your account will delete all your files and data from the apps you use, such as calendar and contacts." : "刪除您的帳號將會刪除您使用的 App 中所有檔案及資料（譬如日曆和聯絡人）。",
    "Account marked for deletion" : "帳號已標記為刪除",
    "This action is irreversible!" : "移除帳戶後將無法復原!",
    "After confirming the deletion of your account, you will be redirected to the login page." : "移除帳戶後，我們將網站導到登入頁面，您將無法再次登入。",
    "You are the only user of this instance, you can't delete your account." : "您是唯一一個在這個實例中的用戶，您無法移除帳戶，請與管理員聯絡。",
    "You are the only admin of this instance, you can't delete your account." : "您是唯一一個在這個實例中的管理員，您無法移除帳戶。",
    "Do you really wish to delete your account?" : "您真的想移除您的帳戶嗎?",
    "Check this to confirm the deletion request" : "勾選這個選項來確認您真的想移除您的帳戶"
},
"nplurals=1; plural=0;");

==> drop_account-2.4.0.tar.gz: drop_account/l10n/zh_TW.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) 刪除了他們的帳號",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) 刪除了他們的帳號",
    "%1$s deleted their account" : "%1$s 刪除了他們的帳號",
    "A user <strong>deleted</strong> its account" : "An user <strong>刪除了</strong>他的帳號",
    "User-Session unexpectedly expired" : "用戶會話意外過期",
    "Successfully sent email" : "電子郵件傳送成功",
    "You have no email set up into your account" : "您的帳號沒有設定電子郵件",
    "Unexpected error sending email. Please contact your administrator." : "傳送電子郵件時發生意外的錯誤。請聯絡您的系統管理員。",
    "Hello," : "歡迎，",
    "Delete account" : "刪除帳號",
    "Cheers!" : "乾杯！",
    "You are the only user on the server, you can't delete your account." : "您是唯一一個在這個實例中的用戶，您無法移除帳戶，請與管理員聯絡。",
    "You are the only admin on the server, you can't delete your account." : "您是唯一一個在這個實例中的管理員，您無法移除帳戶。",
    "Account deletion on %s scheduled" : "刪除帳號",
    "Account on %s deleted" : "刪除帳號",
    "User account deletion" : "刪除使用者帳號",
    "An app to allow users to delete their accounts." : "app 允許使用者刪除他們的帳號.",
    "Account deletion" : "刪除帳號",
    "Allows users to delete themselves their own account." : "允許使用者刪除他們自己的帳號。",
    "Email confirmation" : "電子郵件確認",
    "Require confirmation by email" : "需要透過電子郵件確認",
    "Will require users to click a confirmation link sent by email to confirm their action." : "要求使用者點擊通過電子郵件發送的確認連結來確認其操作。",
    "Delete my account" : "刪除我的帳號",
    "Deleting your account will delete all your files and data from the apps you use, such as calendar and contacts." : "刪除您的帳號將會刪除您使用的 App 中所有檔案及資料（譬如日曆和聯絡人）。",
    "Account marked for deletion" : "帳號已標記為刪除",
    "This action is irreversible!" : "移除帳戶後將無法復原!",
    "After confirming the deletion of your account, you will be redirected to the login page." : "移除帳戶後，我們將網站導到登入頁面，您將無法再次登入。",
    "You are the only user of this instance, you can't delete your account." : "您是唯一一個在這個實例中的用戶，您無法移除帳戶，請與管理員聯絡。",
    "You are the only admin of this instance, you can't delete your account." : "您是唯一一個在這個實例中的管理員，您無法移除帳戶。",
    "Do you really wish to delete your account?" : "您真的想移除您的帳戶嗎?",
    "Check this to confirm the deletion request" : "勾選這個選項來確認您真的想移除您的帳戶"
},
"nplurals=1; plural=0;");
